#include "HistoCollector1D.h"
#include <TCanvas.h>
#include <TLegend.h>
#include <TMath.h>
#include <TROOT.h>

//_________________
void ProcessMesons1D() {

  int PartType = 4;
  //gROOT->ProcessLine(".L HistoCollector1D.cxx+");

  HistoCollector1D mHistoCollector;
  int qInvBins = 40;
  double qInvLo = 0.;
  double qInvHi = 0.4;
  int NCentBins = 9;
  int NKtBins = 24;
  const char* fname = "auau200_kaons_1d.root";
  mHistoCollector.SetFileName(fname);
  mHistoCollector.SetQinvBins(qInvBins,qInvLo,qInvHi);
  mHistoCollector.SetPartType(PartType);
  mHistoCollector.SetCentBins(NCentBins);
  mHistoCollector.SetKtBins(NKtBins);
  mHistoCollector.LoadData();
  
  TH1F *hCorrFctn = mHistoCollector.BuildCentKtCF(1,8,8,10,12);
  hCorrFctn->Draw();
}

